Learn R Programming

tinytiger (version 0.0.11)

tt_new_england_city_divisions: Download TIGER shapes for New England City and Town Area Divisions

Description

Download TIGER shapes for New England City and Town Area Divisions

Usage

tt_new_england_city_divisions(year = 2021)

Value

sf data.frame

Arguments

year

Integer year. Required. 2000 and 2010-2025 are currently supported.

Examples

Run this code
# Wrapped in try due to false positive 304 errors
try(tt_new_england_city_divisions()) # downloads slow on CRAN

Run the code above in your browser using DataLab